<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name></name>
    <message>
        <source>UNKNOWN CUT</source>
        <translation type="obsolete">UKJENT KLYPP</translation>
    </message>
</context>
<context>
    <name>@default</name>
    <message>
        <source>ALL</source>
        <translation type="obsolete">ALLE</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Couldn&apos;t initialize QSql driver!</source>
        <translation type="obsolete">Greidde ikkje setja opp QSql-drivaren!</translation>
    </message>
    <message>
        <source>Couldn&apos;t open mySQL connection!</source>
        <translation type="obsolete">Greidde ikkje kopla til mySQL-databasen!</translation>
    </message>
    <message>
        <source>Sequentially</source>
        <translation type="unfinished">I rekkjefylgje</translation>
    </message>
    <message>
        <source>Randomly</source>
        <translation type="unfinished">Tilfeldig</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished">Ukjent</translation>
    </message>
    <message>
        <source>Feature</source>
        <translation type="unfinished">Eigenskap</translation>
    </message>
    <message>
        <source>Theme Open</source>
        <translation type="unfinished">Opningsvignett</translation>
    </message>
    <message>
        <source>Theme Close</source>
        <translation type="unfinished">Sluttvignett</translation>
    </message>
    <message>
        <source>Theme Open/Close</source>
        <translation type="unfinished">Opnings/sluttvignett</translation>
    </message>
    <message>
        <source>Background</source>
        <translation type="unfinished">Bakgrunnen</translation>
    </message>
    <message>
        <source>Commercial/Jingle/Promo</source>
        <translation type="unfinished">Reklame/vignett/promo</translation>
    </message>
    <message>
        <source>UNKNOWN CUT</source>
        <translation type="unfinished">UKJENT KLYPP</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation type="unfinished">Manuell</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished">Spel</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="unfinished">Overgang</translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="unfinished">Tid</translation>
    </message>
    <message>
        <source>Panel</source>
        <translation type="unfinished">Rute</translation>
    </message>
    <message>
        <source>Macro</source>
        <translation type="unfinished">Makro</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation type="unfinished">SPEL</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation type="unfinished">OVERGANG</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="unfinished">STOPP</translation>
    </message>
    <message>
        <source>UNKNOWN</source>
        <translation type="unfinished">UKJENT</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="unfinished">Lyd</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation type="unfinished">Markør</translation>
    </message>
    <message>
        <source>Open Bracket</source>
        <translation type="unfinished">Startklamme</translation>
    </message>
    <message>
        <source>Close Bracket</source>
        <translation type="unfinished">Sluttklamme</translation>
    </message>
    <message>
        <source>ChainTo</source>
        <translation type="obsolete">LenkTil</translation>
    </message>
    <message>
        <source>Track</source>
        <translation type="unfinished">Spor</translation>
    </message>
    <message>
        <source>Link</source>
        <translation type="obsolete">Lenkje</translation>
    </message>
    <message>
        <source>Traffic</source>
        <translation type="unfinished">Trafikk</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished">Musikk</translation>
    </message>
    <message>
        <source>RDLogManager</source>
        <translation type="unfinished">RDLoggredigering</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation type="unfinished">Sporleggjar</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation type="unfinished">Opptak</translation>
    </message>
    <message>
        <source>Macro Event</source>
        <translation type="unfinished">Makro-hending</translation>
    </message>
    <message>
        <source>Switch Event</source>
        <translation type="unfinished">Byte-hending</translation>
    </message>
    <message>
        <source>Playout</source>
        <translation type="unfinished">Spel ut</translation>
    </message>
    <message>
        <source>Download</source>
        <translation type="unfinished">Last ned</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation type="unfinished">Last opp</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Short Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Low Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>High Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uploading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Internal Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Interrupted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Playing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Waiting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device Busy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Such Cart/Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown Audio Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CBSI DeltaFlex Traffic Reconciliation v2.01</source>
        <translation type="unfinished">CBSI DeltaFlex Traffic Reconciliation v2.01</translation>
    </message>
    <message>
        <source>Text Log</source>
        <translation type="unfinished">Tekstlogg</translation>
    </message>
    <message>
        <source>ASCAP/BMI Electronic Music Report</source>
        <translation type="unfinished">ASCAP/BMI elektronisk musikkrapport</translation>
    </message>
    <message>
        <source>Technical Playout Report</source>
        <translation type="unfinished">Teknisk utspelingsrapport</translation>
    </message>
    <message>
        <source>SoundExchange Statutory License Report</source>
        <translation type="unfinished">SoundExchange Statutory License-rapport</translation>
    </message>
    <message>
        <source>RadioTraffic.com Traffic Reconciliation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VisualTraffic Reconciliation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CounterPoint Traffic Reconciliation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music1 Reconciliation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished">Annan</translation>
    </message>
    <message>
        <source>AM</source>
        <translation type="unfinished">AM</translation>
    </message>
    <message>
        <source>FM</source>
        <translation type="unfinished">FM</translation>
    </message>
    <message>
        <source>Report complete!</source>
        <translation type="unfinished">Rapport ferdig!</translation>
    </message>
    <message>
        <source>Report canceled!</source>
        <translation type="unfinished">Rapport avbroten!</translation>
    </message>
    <message>
        <source>Unable to open report file!</source>
        <translation type="unfinished">Greidde ikkje opna rapportfil!</translation>
    </message>
    <message>
        <source>Music Summary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WideOrbit Traffic Reconciliation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown Position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NPR/DS SoundExchange Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music Playout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main Log Output 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main Log Output 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Panel First Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aux Log 1 Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aux Log 2 Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Panel Second Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Panel Third Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Panel Fourth Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audition/Cue Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Panel Fifth and Later Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>invalid SQL or failed DB connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished">Alle</translation>
    </message>
    <message>
        <source>Relative</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NaturalLog Reconciliation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LiveAssist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Classical Music Playout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>reserved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mr. Master Reconciliation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spin Count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>feature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>promo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fade</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NoTime</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MusicLink</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TrafficLink</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>new cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host already exists!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>host already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>service already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>template service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>does not exist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>template host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished">Klypp</translation>
    </message>
    <message>
        <source>Log already exists!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>No such service!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No such group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No free cart available in group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to open database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>is</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Database version mismatch, should be</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rule broken: Max. in a Row/Min. Wait for </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rule broken: Do not schedule </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>after</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rule broken: Do not schedule</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>is overscheduled by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>is underscheduled by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>is not playable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Couldn&apos;t initialize MySql driver!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Couldn&apos;t open MySQL connection on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DB connection re-established</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not re-establish DB connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid arguments specified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Specified configuration was not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>One or more Rivendell modules are active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No running as root</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>systemctl(8) crashed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rivendell service shutdown failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio store unmount failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio store mount failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rivendell service startup failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current configuration was not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Synlink creation failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid configuration name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>mount(8) crashed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>does not have a Hosts entry in the database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open RDAdmin-&gt;ManageHosts-&gt;Add to create one.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to update automounter configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PCM8</source>
        <translation type="unfinished">PCM8</translation>
    </message>
    <message>
        <source>PCM16</source>
        <translation type="unfinished">PCM16</translation>
    </message>
    <message>
        <source>Float32</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MPEG Layer I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MPEG Layer II (MP2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MPEG Layer III (MP3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dolby AC2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dolby AC3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OggVorbis</source>
        <translation type="unfinished">Ogg Vorbis</translation>
    </message>
    <message>
        <source>PCM24</source>
        <translation type="unfinished">PCM24</translation>
    </message>
    <message>
        <source>RIFF/WAVE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Raw MPEG Bitstream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ogg Bitstream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ATX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TMC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Raw FLAC Bitstream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM-BOS Hybrid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AIFF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MP4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rule broken: Title separation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> with sched code(s): </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rule broken: Artist separation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No carts found in group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>-- End of List --</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CounterPoint Traffic Reconciliation v2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Timed(Wait)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Timed(Start), </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Timed(MakeNext), </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Traffic, </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music, </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scheduler, </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Inline Traffic, </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Results Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LOG CHAIN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LINK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[cart not found]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[music link]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[traffic link]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>whitespace is not permitted in service names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>new profile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[none]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must supply a &quot;from&quot; address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unable to start sendmail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sendmail crashed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sendmail returned non-zero exit code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>is invalid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Original RadioTraffic.com Traffic Reconciliation (DEPRECATED)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disc Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disc Artist</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDAddCart</name>
    <message>
        <source>&amp;Group:</source>
        <translation>&amp;Gruppe:</translation>
    </message>
    <message>
        <source>&amp;New Cart Number:</source>
        <translation>&amp;Nytt korgnummer</translation>
    </message>
    <message>
        <source>&amp;New Cart Type:</source>
        <translation>&amp;Ny korgtype:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Lyd</translation>
    </message>
    <message>
        <source>Macro</source>
        <translation>Makro</translation>
    </message>
    <message>
        <source>[new cart]</source>
        <translation>[ny korg]</translation>
    </message>
    <message>
        <source>&amp;New Cart Title:</source>
        <translation>&amp;Nytt namn på korga:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>No Available Cart Numbers</source>
        <translation>Ingen korgnummer tilgjengelege</translation>
    </message>
    <message>
        <source>There are no more available cart numbers for the group!</source>
        <translation>Det er ikkje fleire korgnummer i denne gruppa!</translation>
    </message>
    <message>
        <source>Invalid Number</source>
        <translation>Ugyldig nummer</translation>
    </message>
    <message>
        <source>Invalid Cart Number!</source>
        <translation>Ugyldig korgnummer</translation>
    </message>
    <message>
        <source>Title Required</source>
        <translation>Namn er kravd</translation>
    </message>
    <message>
        <source>You must enter a cart title!</source>
        <translation>Du må skriva inn eit namn på korga!</translation>
    </message>
    <message>
        <source>The cart number is outside of the permitted range for this group!</source>
        <translation>Korgnummeret er utanfor det lovlege omfanget for denne gruppa!</translation>
    </message>
    <message>
        <source>Cart Exists</source>
        <translation>Korga finst alt</translation>
    </message>
    <message>
        <source>This cart already exists.</source>
        <translation>Denne korga finst frå før.</translation>
    </message>
    <message>
        <source>Duplicate Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The cart title must be unique!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Cart</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDAddLog</name>
    <message>
        <source>Create Log</source>
        <translation>Opprett logg</translation>
    </message>
    <message>
        <source>&amp;New Log Name:</source>
        <translation>&amp;Nytt namn på loggen:</translation>
    </message>
    <message>
        <source>&amp;Service:</source>
        <translation>&amp;Tenest:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>RDLogEdit</source>
        <translation>RDLogEdit</translation>
    </message>
    <message>
        <source>The name is invalid!</source>
        <translation type="obsolete">Namnet er ikkje gyldig!</translation>
    </message>
    <message>
        <source>The service is invalid!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDApplication</name>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>systemctl(1) crashed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>systemctl(1) returned exit code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rivendell service is not active.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>prior instance already running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unable to open database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unable to start a service component</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown/invalid command option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unable to overwrite output [-P given]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>no such service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>no such log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>no such report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>log generation failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>schedule import failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>insufficient permissions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>report generation failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>one or more audio imports failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown dropbox id</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>no such group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>invalid cart number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>no such scheduler code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>bad ticket</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDAudioSettingsDialog</name>
    <message>
        <source>Edit Settings</source>
        <translation type="obsolete">Rediger innstillingar</translation>
    </message>
    <message>
        <source>Default &amp;Format:</source>
        <translation type="obsolete">Standard&amp;format:</translation>
    </message>
    <message>
        <source>Default &amp;Channels:</source>
        <translation type="obsolete">Standard tal på &amp;kanalar:</translation>
    </message>
    <message>
        <source>Default &amp;Sample Rate:</source>
        <translation type="obsolete">Standard &amp;punktprøverate:</translation>
    </message>
    <message>
        <source>Default &amp;Bitrate:</source>
        <translation type="obsolete">Standard &amp;bitrate:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Avbryt</translation>
    </message>
    <message>
        <source>PCM16</source>
        <translation type="obsolete">PCM16</translation>
    </message>
    <message>
        <source>OggVorbis</source>
        <translation type="obsolete">Ogg Vorbis</translation>
    </message>
    <message>
        <source>MPEG Layer 2</source>
        <translation type="obsolete">MPEG lag 2</translation>
    </message>
    <message>
        <source>MPEG Layer 3</source>
        <translation type="obsolete">MPEG lag 3</translation>
    </message>
</context>
<context>
    <name>RDButtonDialog</name>
    <message>
        <source>Edit Button</source>
        <translation>Rediger knapp</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation>Merke:</translation>
    </message>
    <message>
        <source>Cart:</source>
        <translation>Korg:</translation>
    </message>
    <message>
        <source>Set
Cart</source>
        <translation>Set opp
korg</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Tøm</translation>
    </message>
    <message>
        <source>Set
Color</source>
        <translation>Set opp 
farge</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>NOT FOUND</source>
        <translation>IKKJE FUNNE</translation>
    </message>
</context>
<context>
    <name>RDCardSelector</name>
    <message>
        <source>Card:</source>
        <translation>Kort:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
</context>
<context>
    <name>RDCart</name>
    <message>
        <source>Sequentially</source>
        <translation type="obsolete">I rekkjefylgje</translation>
    </message>
    <message>
        <source>Randomly</source>
        <translation type="obsolete">Tilfeldig</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Ukjent</translation>
    </message>
    <message>
        <source>Feature</source>
        <translation type="obsolete">Eigenskap</translation>
    </message>
    <message>
        <source>Theme Open</source>
        <translation type="obsolete">Opningsvignett</translation>
    </message>
    <message>
        <source>Theme Close</source>
        <translation type="obsolete">Sluttvignett</translation>
    </message>
    <message>
        <source>Theme Open/Close</source>
        <translation type="obsolete">Opnings/sluttvignett</translation>
    </message>
    <message>
        <source>Background</source>
        <translation type="obsolete">Bakgrunnen</translation>
    </message>
    <message>
        <source>Commercial/Jingle/Promo</source>
        <translation type="obsolete">Reklame/vignett/promo</translation>
    </message>
</context>
<context>
    <name>RDCartDialog</name>
    <message>
        <source>Select Cart</source>
        <translation>Vel korg</translation>
    </message>
    <message>
        <source>Please Wait...</source>
        <translation>Vent litt...</translation>
    </message>
    <message>
        <source>Cart Filter:</source>
        <translation>Korgfilter:</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Søk</translation>
    </message>
    <message>
        <source>C&amp;lear</source>
        <translation>&amp;Tøm</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Gruppe:</translation>
    </message>
    <message>
        <source>NUMBER</source>
        <translation type="obsolete">NUMMER</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation type="obsolete">LENGD</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="obsolete">TITTEL</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation type="obsolete">ARTIST</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="obsolete">GRUPPE</translation>
    </message>
    <message>
        <source>CLIENT</source>
        <translation type="obsolete">KLIENT</translation>
    </message>
    <message>
        <source>AGENCY</source>
        <translation type="obsolete">AGENT</translation>
    </message>
    <message>
        <source>USER DEF</source>
        <translation type="obsolete">BRUKARDEFINERT</translation>
    </message>
    <message>
        <source>START</source>
        <translation type="obsolete">START</translation>
    </message>
    <message>
        <source>END</source>
        <translation type="obsolete">SLUTT</translation>
    </message>
    <message>
        <source>Send to
&amp;Editor</source>
        <translation>Send til R&amp;edigering</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>ALLE</translation>
    </message>
    <message>
        <source>Show Only First</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Matches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scheduler Code:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load From
&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to create temporary cart for import!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Imported from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Importing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished">Lengd</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Composer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Conductor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Agency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Def</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished">Slutten</translation>
    </message>
    <message>
        <source>Open Audio File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDCddbLookup</name>
    <message>
        <source>CDDB Query</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">OK</translation>
    </message>
</context>
<context>
    <name>RDCueEdit</name>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished">Slutten</translation>
    </message>
    <message>
        <source>&amp;Recue</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDCueEditDialog</name>
    <message>
        <source>Set Cue Point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Avbryt</translation>
    </message>
</context>
<context>
    <name>RDCutDialog</name>
    <message>
        <source>Select Cut</source>
        <translation>Vel klypp</translation>
    </message>
    <message>
        <source>Please Wait...</source>
        <translation>Vent litt...</translation>
    </message>
    <message>
        <source>Cart Filter:</source>
        <translation>Korgfilter:</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Søk</translation>
    </message>
    <message>
        <source>C&amp;lear</source>
        <translation>&amp;Tøm</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Gruppe:</translation>
    </message>
    <message>
        <source>Carts</source>
        <translation>Korger</translation>
    </message>
    <message>
        <source>NUMBER</source>
        <translation type="obsolete">NUMMER</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="obsolete">TITTEL</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="obsolete">GRUPPE</translation>
    </message>
    <message>
        <source>Cuts</source>
        <translation>Klypp</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="obsolete">SKILDRING</translation>
    </message>
    <message>
        <source>&amp;Add New
Cart</source>
        <translation>&amp;Legg til ny korg</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Tøm</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>ALLE</translation>
    </message>
    <message>
        <source>Show Only First</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Matches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scheduler Code:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDDateDialog</name>
    <message>
        <source>Select Date</source>
        <translation>Vel dato</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
</context>
<context>
    <name>RDDatePicker</name>
    <message>
        <source>Mo</source>
        <translation>Må</translation>
    </message>
    <message>
        <source>Tu</source>
        <translation>Ty</translation>
    </message>
    <message>
        <source>We</source>
        <translation>On</translation>
    </message>
    <message>
        <source>Th</source>
        <translation>To</translation>
    </message>
    <message>
        <source>Fr</source>
        <translation>Fr</translation>
    </message>
    <message>
        <source>Sa</source>
        <translation>La</translation>
    </message>
    <message>
        <source>Su</source>
        <translation>Su</translation>
    </message>
</context>
<context>
    <name>RDDiscLookup</name>
    <message>
        <source>Multiple Matches Found!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to read CD.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Ukjent</translation>
    </message>
    <message>
        <source>Unable to create temporary directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD-TEXT</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDEditAudio</name>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Lagra</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>Amplitude</source>
        <translation>Lydstyrke</translation>
    </message>
    <message>
        <source>Zoom
In</source>
        <translation type="obsolete">Zoom
inn</translation>
    </message>
    <message>
        <source>Zoom
Out</source>
        <translation type="obsolete">Zoom
ut</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Tid</translation>
    </message>
    <message>
        <source>Full
In</source>
        <translation>Heilt
inn</translation>
    </message>
    <message>
        <source>Full
Out</source>
        <translation>Heilt
ut</translation>
    </message>
    <message>
        <source>Goto</source>
        <translation>Gå til</translation>
    </message>
    <message>
        <source>Cursor</source>
        <translation>Markør</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Heim</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Slutten</translation>
    </message>
    <message>
        <source>Cut
Start</source>
        <translation>Klypp-
start</translation>
    </message>
    <message>
        <source>Cut
End</source>
        <translation>Klypp-
slutt</translation>
    </message>
    <message>
        <source>Talk
Start</source>
        <translation>Tale- 
start</translation>
    </message>
    <message>
        <source>Segue
Start</source>
        <translation>Overgang-
start</translation>
    </message>
    <message>
        <source>Segue
End</source>
        <translation>Overgang-
slutt</translation>
    </message>
    <message>
        <source>Fade
Up</source>
        <translation>Ton
inn</translation>
    </message>
    <message>
        <source>Hook
Start</source>
        <translation>Knagg-
start</translation>
    </message>
    <message>
        <source>Hook
End</source>
        <translation>Knagg-
slutt</translation>
    </message>
    <message>
        <source> dB</source>
        <translation>dB</translation>
    </message>
    <message>
        <source>Threshold</source>
        <translation>Terskel</translation>
    </message>
    <message>
        <source>Trim
Start</source>
        <translation>Skjere-
start</translation>
    </message>
    <message>
        <source>Trim
End</source>
        <translation>Skjere-
slutt</translation>
    </message>
    <message>
        <source>Cut Gain</source>
        <translation>Dempevolum</translation>
    </message>
    <message>
        <source>Remove
Marker</source>
        <translation>Fjern
markør</translation>
    </message>
    <message>
        <source>No Fade on Segue Out</source>
        <translation>Inga uttoning ved Overgang ut</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Posisjon</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Lengd</translation>
    </message>
    <message>
        <source>Delete Talk Markers</source>
        <translation>Slett talemarkørar</translation>
    </message>
    <message>
        <source>Delete Segue Markers</source>
        <translation>Slett overgangsmarkørar</translation>
    </message>
    <message>
        <source>Delete Hook Markers</source>
        <translation>Slett knaggmarkørar</translation>
    </message>
    <message>
        <source>Delete Fade Up Marker</source>
        <translation>Slett Ton inn-markør</translation>
    </message>
    <message>
        <source>Delete Fade Down Marker</source>
        <translation>Slett Ton ut-markør</translation>
    </message>
    <message>
        <source>dB</source>
        <translation>dB</translation>
    </message>
    <message>
        <source>&lt;none&gt;</source>
        <translation>&lt;ingen&gt;</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Klypp</translation>
    </message>
    <message>
        <source>Talk</source>
        <translation>Tale</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation>Overgang</translation>
    </message>
    <message>
        <source>Hook</source>
        <translation>Knagg</translation>
    </message>
    <message>
        <source>Fade Up</source>
        <translation>Ton inn</translation>
    </message>
    <message>
        <source>Fade Down</source>
        <translation>Ton ut</translation>
    </message>
    <message>
        <source>L</source>
        <translation>V</translation>
    </message>
    <message>
        <source>R</source>
        <translation>H</translation>
    </message>
    <message>
        <source>Rivendell Web Service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to download peak data, error was:
&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marker Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Less than half of the audio is playable with these marker settings.
Are you sure you want to save?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>More than half of the audio will be faded with these marker settings.
Are you sure you want to save?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDEditPanelName</name>
    <message>
        <source>Edit Panel Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Panel &amp;Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Avbryt</translation>
    </message>
</context>
<context>
    <name>RDExceptionDialog</name>
    <message>
        <source>Rivendell Exception Report</source>
        <translation type="obsolete">Unntaksrapport frå Rivendell</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation type="obsolete">&amp;Lagre</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">Lu&amp;kk</translation>
    </message>
    <message>
        <source>Text (*.txt *.TXT)
All Files (*.*)</source>
        <translation type="obsolete">Tekst (*.txt *.TXT)
Alle filer (*.*)</translation>
    </message>
    <message>
        <source>Export File</source>
        <translation type="obsolete">Eksporter fil</translation>
    </message>
    <message>
        <source>The file</source>
        <translation type="obsolete">Fila</translation>
    </message>
    <message>
        <source>already exists!
Overwrite?</source>
        <translation type="obsolete">finst frå før!
Skriv over?</translation>
    </message>
    <message>
        <source>File Exists</source>
        <translation type="obsolete">Fila finst</translation>
    </message>
    <message>
        <source>Unable to open file</source>
        <translation type="obsolete">Greier ikkje opna fila</translation>
    </message>
    <message>
        <source>for writing!</source>
        <translation type="obsolete">for skriving!</translation>
    </message>
    <message>
        <source>File Error</source>
        <translation type="obsolete">Filfeil</translation>
    </message>
</context>
<context>
    <name>RDExportSettingsDialog</name>
    <message>
        <source>Edit Export Settings</source>
        <translation type="obsolete">Rediger eksportinnstillingar</translation>
    </message>
    <message>
        <source>&amp;Channels:</source>
        <translation type="obsolete">&amp;Kanalar:</translation>
    </message>
    <message>
        <source>&amp;Sample Rate:</source>
        <translation type="obsolete">&amp;Punktprøverate:</translation>
    </message>
    <message>
        <source>&amp;Bitrate:</source>
        <translation type="obsolete">&amp;Bitrate:</translation>
    </message>
    <message>
        <source>&amp;Quality:</source>
        <translation type="obsolete">&amp;Kvalitet:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>PCM16</source>
        <translation>PCM16</translation>
    </message>
    <message>
        <source>FLAC</source>
        <translation>FLAC</translation>
    </message>
    <message>
        <source>MPEG Layer 2</source>
        <translation>MPEG lag 2</translation>
    </message>
    <message>
        <source>MPEG Layer 3</source>
        <translation>MPEG lag 3</translation>
    </message>
    <message>
        <source>OggVorbis</source>
        <translation>Ogg Vorbis</translation>
    </message>
    <message>
        <source>VBR</source>
        <translation>VBR</translation>
    </message>
    <message>
        <source>32 kbps</source>
        <translation>32 kbps</translation>
    </message>
    <message>
        <source>64 kbps</source>
        <translation>64 kbps</translation>
    </message>
    <message>
        <source>96 kbps</source>
        <translation>96 kbps</translation>
    </message>
    <message>
        <source>128 kbps</source>
        <translation>128 kbps</translation>
    </message>
    <message>
        <source>160 kbps</source>
        <translation>160 kbps</translation>
    </message>
    <message>
        <source>192 kbps</source>
        <translation>192 kbps</translation>
    </message>
    <message>
        <source>224 kbps</source>
        <translation>224 kbps</translation>
    </message>
    <message>
        <source>256 kbps</source>
        <translation>256 kbps</translation>
    </message>
    <message>
        <source>288 kbps</source>
        <translation>288 kbps</translation>
    </message>
    <message>
        <source>320 kbps</source>
        <translation>320 kbps</translation>
    </message>
    <message>
        <source>352 kbps</source>
        <translation>352 kbps</translation>
    </message>
    <message>
        <source>384 kbps</source>
        <translation>384 kbps</translation>
    </message>
    <message>
        <source>416 kbps</source>
        <translation>416 kbps</translation>
    </message>
    <message>
        <source>448 kbps</source>
        <translation>448 kbps</translation>
    </message>
    <message>
        <source>48 kbps</source>
        <translation>48 kbps</translation>
    </message>
    <message>
        <source>56 kbps</source>
        <translation>56 kbps</translation>
    </message>
    <message>
        <source>80 kbps</source>
        <translation>80 kbps</translation>
    </message>
    <message>
        <source>112 kbps</source>
        <translation>112 kbps</translation>
    </message>
    <message>
        <source>40 kbps</source>
        <translation>40 kbps</translation>
    </message>
    <message>
        <source>8 kbps</source>
        <translation>8 kbps</translation>
    </message>
    <message>
        <source>16 kbps</source>
        <translation>16 kbps</translation>
    </message>
    <message>
        <source>24 kbps</source>
        <translation>24 kbps</translation>
    </message>
    <message>
        <source>144 kbps</source>
        <translation>144 kbps</translation>
    </message>
    <message>
        <source>PCM24</source>
        <translation type="unfinished">PCM24</translation>
    </message>
    <message>
        <source>Edit Audio Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>is already in use.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normalization Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autotrim Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation type="unfinished">dBFS</translation>
    </message>
</context>
<context>
    <name>RDGetAth</name>
    <message>
        <source>Enter ATH</source>
        <translation>Skriv inn lyttetimar</translation>
    </message>
    <message>
        <source>Enter the agreggate tuning hours (ATH)
figure for the report period.
(Supplied by your streaming provider).</source>
        <translation>Skriv inn totalt lyttetimetal
for rapportperioden.
(Oppgjeve av strøymeleverandøren din).</translation>
    </message>
    <message>
        <source>ATH:</source>
        <translation>Lyttetimar:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>Invalid ATH</source>
        <translation>Ugyldig lyttetimetal</translation>
    </message>
    <message>
        <source>You must provide a valid ATH figure!</source>
        <translation>Du må oppgje eit gyldig tal på lyttetimar!</translation>
    </message>
</context>
<context>
    <name>RDGetPasswd</name>
    <message>
        <source>Enter Password</source>
        <translation>Skriv inn passord</translation>
    </message>
    <message>
        <source>Enter password</source>
        <translation>Skriv inn passord</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
</context>
<context>
    <name>RDGpioSelector</name>
    <message>
        <source>Pin:</source>
        <translation>Pin-nummer:</translation>
    </message>
</context>
<context>
    <name>RDImagePickerModel</name>
    <message>
        <source>Image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDImportAudio</name>
    <message>
        <source>Import/Export Audio File</source>
        <translation>Importer/eksporter lydfil</translation>
    </message>
    <message>
        <source>Import File</source>
        <translation>Importer fil</translation>
    </message>
    <message>
        <source>Filename:</source>
        <translation>Filnamn:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Vel</translation>
    </message>
    <message>
        <source>Import file metadata</source>
        <translation>Importer metadata frå fil</translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation>Kanalar:</translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation>Autoskjer</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nivå:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dBFS</translation>
    </message>
    <message>
        <source>Export File</source>
        <translation>Eksporter fil</translation>
    </message>
    <message>
        <source>Export file metadata</source>
        <translation>Eksporter metadata frå fil</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>S&amp;et</source>
        <translation>S&amp;et</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normaliser</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation>&amp;Importer</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksporter</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importer</translation>
    </message>
    <message>
        <source>Import Audio File</source>
        <translation>Importer lydfil</translation>
    </message>
    <message>
        <source>File does not exist!</source>
        <translation>Fila finst ikkje!</translation>
    </message>
    <message>
        <source>Cannot open file!</source>
        <translation type="obsolete">Greier ikkje opna fila!</translation>
    </message>
    <message>
        <source>Unsupported file type!</source>
        <translation type="obsolete">Filtypen er ikkje støtta!</translation>
    </message>
    <message>
        <source>Audio Exists</source>
        <translation type="obsolete">Lyd finst</translation>
    </message>
    <message>
        <source>This will overwrite the existing recording.
Do you want to proceed?</source>
        <translation type="obsolete">Dette skriv over opptaket ditt.
Vil du halda fram?</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation type="obsolete">Tom utklyppstavle</translation>
    </message>
    <message>
        <source>Importing this cut will also empty the clipboard.
Do you still want to proceed?</source>
        <translation type="obsolete">Viss du importerer dette klyppet, tømer du utklyppstavla.
Vil du halda fram?</translation>
    </message>
    <message>
        <source>Import Complete</source>
        <translation>Import ferdig</translation>
    </message>
    <message>
        <source>Import complete!</source>
        <translation>Importen er ferdig!</translation>
    </message>
    <message>
        <source>Import Aborted</source>
        <translation type="obsolete">Import avbroten</translation>
    </message>
    <message>
        <source>The import has been aborted.</source>
        <translation type="obsolete">Importen vart avbroten.</translation>
    </message>
    <message>
        <source>Import Failed</source>
        <translation type="obsolete">Importfeil</translation>
    </message>
    <message>
        <source>The importer encountered an error.
Please check your importer configuration and try again.</source>
        <translation type="obsolete">Det var ein feil med importen.
Sjå over importoppsettet ditt og prøv att.</translation>
    </message>
    <message>
        <source>File Exists</source>
        <translation>Fila finst</translation>
    </message>
    <message>
        <source>The selected file already exists!
Do you want to overwrite it?</source>
        <translation>Denne fila finst alt!
Vil du skriva over henne?</translation>
    </message>
    <message>
        <source>File Error</source>
        <translation type="obsolete">Filfeil</translation>
    </message>
    <message>
        <source>Cannot open file in archive!</source>
        <translation type="obsolete">Greier ikkje opna fila i arkivet!</translation>
    </message>
    <message>
        <source>Unsupported file type in archive!</source>
        <translation type="obsolete">Filtypen i arkivet er ikkje støtta!</translation>
    </message>
    <message>
        <source>No Access</source>
        <translation type="obsolete">Ingen tilgang</translation>
    </message>
    <message>
        <source>Unable to open the file for writing!</source>
        <translation type="obsolete">Greier ikkje opna fila for skriving!</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">OK</translation>
    </message>
    <message>
        <source>Export Complete</source>
        <translation>Eksport ferdig</translation>
    </message>
    <message>
        <source>Export complete!</source>
        <translation>Eksporten er ferdig!</translation>
    </message>
    <message>
        <source>Export Aborted</source>
        <translation type="obsolete">Eksport avbroten</translation>
    </message>
    <message>
        <source>The export has been aborted.</source>
        <translation type="obsolete">Eksporten vart avbroten.</translation>
    </message>
    <message>
        <source>Export Failed</source>
        <translation type="obsolete">Eksportfeil</translation>
    </message>
    <message>
        <source>The Exporter encountered an error.
Please check your configuration and try again.</source>
        <translation type="obsolete">Det var ein feil med eksporten.
Sjekk eksportoppsettet ditt og prøv att.</translation>
    </message>
    <message>
        <source>Export Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Abort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Audio File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Audio File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDIntegerDialog</name>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Avbryt</translation>
    </message>
</context>
<context>
    <name>RDLicense</name>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">Lu&amp;kk</translation>
    </message>
    <message>
        <source>GNU Public License v2</source>
        <translation type="obsolete">GNU Public-lisensen, versjon 2</translation>
    </message>
</context>
<context>
    <name>RDListGroups</name>
    <message>
        <source>Select Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NAME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="unfinished">SKILDRING</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Avbryt</translation>
    </message>
</context>
<context>
    <name>RDListLogs</name>
    <message>
        <source>DESCRIPTION</source>
        <translation type="obsolete">SKILDRING</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ALL</source>
        <translation type="obsolete">ALLE</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Service</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDListSelector</name>
    <message>
        <source>Available Services</source>
        <translation>Tilgjengelege tenester</translation>
    </message>
    <message>
        <source>Add &gt;&gt;</source>
        <translation>Legg til &gt;&gt;</translation>
    </message>
    <message>
        <source>&lt;&lt; Remove</source>
        <translation>&lt;&lt; Fjern</translation>
    </message>
    <message>
        <source>Active Services</source>
        <translation>Aktive tenester</translation>
    </message>
</context>
<context>
    <name>RDLogFilter</name>
    <message>
        <source>Service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished">Tøm</translation>
    </message>
    <message>
        <source>Show Only Recent Logs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ALL</source>
        <translation type="unfinished">ALLE</translation>
    </message>
</context>
<context>
    <name>RDLogLine</name>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Ukjent</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation type="obsolete">Manuell</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="obsolete">Spel</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="obsolete">Overgang</translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="obsolete">Tid</translation>
    </message>
    <message>
        <source>Panel</source>
        <translation type="obsolete">Rute</translation>
    </message>
    <message>
        <source>Macro</source>
        <translation type="obsolete">Makro</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation type="obsolete">SPEL</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation type="obsolete">OVERGANG</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="obsolete">STOPP</translation>
    </message>
    <message>
        <source>OVERLAP</source>
        <translation type="obsolete">OVERLAPP</translation>
    </message>
    <message>
        <source>UNKNOWN</source>
        <translation type="obsolete">UKJENT</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="obsolete">Lyd</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation type="obsolete">Markør</translation>
    </message>
    <message>
        <source>Open Bracket</source>
        <translation type="obsolete">Startklamme</translation>
    </message>
    <message>
        <source>Close Bracket</source>
        <translation type="obsolete">Sluttklamme</translation>
    </message>
    <message>
        <source>ChainTo</source>
        <translation type="obsolete">LenkTil</translation>
    </message>
    <message>
        <source>Track</source>
        <translation type="obsolete">Spor</translation>
    </message>
    <message>
        <source>Link</source>
        <translation type="obsolete">Lenkje</translation>
    </message>
    <message>
        <source>Traffic</source>
        <translation type="obsolete">Trafikk</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="obsolete">Musikk</translation>
    </message>
    <message>
        <source>RDLogManager</source>
        <translation type="obsolete">RDLoggredigering</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation type="obsolete">Sporleggjar</translation>
    </message>
</context>
<context>
    <name>RDMbLookup</name>
    <message>
        <source>Connection Exception</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Result</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LastHTTPCode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LastErrorMessage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Timeout Exception</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentication Exception</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fetch Exception</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Request Exception</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lookup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resource Not Found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDPanelButton</name>
    <message>
        <source>No Audio</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDPasswd</name>
    <message>
        <source>Change Password</source>
        <translation>Endre passord</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>&amp;Passord:</translation>
    </message>
    <message>
        <source>C&amp;onfirm:</source>
        <translation>&amp;Stadfest:</translation>
    </message>
    <message>
        <source>Password Mismatch</source>
        <translation>Passorda er ikkje like</translation>
    </message>
    <message>
        <source>The passwords don&apos;t match,
please try again!</source>
        <translation>Passorda dine er ikkje like,
prøv ein gong til!</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>RDProcess</name>
    <message>
        <source>no such program</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>process crashed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>process returned exit code</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDRecording</name>
    <message>
        <source>Recording</source>
        <translation type="obsolete">Opptak</translation>
    </message>
    <message>
        <source>Macro Event</source>
        <translation type="obsolete">Makro-hending</translation>
    </message>
    <message>
        <source>Switch Event</source>
        <translation type="obsolete">Byte-hending</translation>
    </message>
    <message>
        <source>Playout</source>
        <translation type="obsolete">Spel ut</translation>
    </message>
    <message>
        <source>Download</source>
        <translation type="obsolete">Last ned</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation type="obsolete">Last opp</translation>
    </message>
</context>
<context>
    <name>RDRehash</name>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Internal Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDXport service returned an error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid user or password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio does not exist</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDRenderer</name>
    <message>
        <source>no such cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>no such cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Using temporary file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pass 2 of 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Writing output file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pass 1 of 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pass 1 of 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Importing cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>first-time event not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>last-time event not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="unfinished">STOPP</translation>
    </message>
    <message>
        <source>FAIL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NO AUDIO AVAILABLE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SKIP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>--- end of log ---</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unable to open output file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>log render halted at line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>due to STOP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>at line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>failed to play (NO AUDIO AVAILABLE)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rendered log is too long!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDReport</name>
    <message>
        <source>CBSI DeltaFlex Traffic Reconciliation v2.01</source>
        <translation type="obsolete">CBSI DeltaFlex Traffic Reconciliation v2.01</translation>
    </message>
    <message>
        <source>Text Log</source>
        <translation type="obsolete">Tekstlogg</translation>
    </message>
    <message>
        <source>ASCAP/BMI Electronic Music Report</source>
        <translation type="obsolete">ASCAP/BMI elektronisk musikkrapport</translation>
    </message>
    <message>
        <source>Technical Playout Report</source>
        <translation type="obsolete">Teknisk utspelingsrapport</translation>
    </message>
    <message>
        <source>SoundExchange Statutory License Report</source>
        <translation type="obsolete">SoundExchange Statutory License-rapport</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Ukjent</translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="obsolete">Annan</translation>
    </message>
    <message>
        <source>AM</source>
        <translation type="obsolete">AM</translation>
    </message>
    <message>
        <source>FM</source>
        <translation type="obsolete">FM</translation>
    </message>
    <message>
        <source>Report complete!</source>
        <translation type="obsolete">Rapport ferdig!</translation>
    </message>
    <message>
        <source>Report canceled!</source>
        <translation type="obsolete">Rapport avbroten!</translation>
    </message>
    <message>
        <source>Unable to open report file!</source>
        <translation type="obsolete">Greidde ikkje opna rapportfil!</translation>
    </message>
</context>
<context>
    <name>RDSoundPanel</name>
    <message>
        <source>Play All</source>
        <translation>Spel alle</translation>
    </message>
    <message>
        <source>Play Hook</source>
        <translation>Spel knagg</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Nullstill</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>Setup</source>
        <translation>Oppsett</translation>
    </message>
    <message>
        <source>Cart</source>
        <translation>Korg</translation>
    </message>
    <message>
        <source>Panel</source>
        <translation>Rute</translation>
    </message>
</context>
<context>
    <name>RDSqlDatabaseStatus</name>
    <message>
        <source>Database connection restored.</source>
        <translation type="obsolete">Databasetilkoplinga er gjenoppretta.</translation>
    </message>
    <message>
        <source>Database connection failed : </source>
        <translation type="obsolete">Feil med databasetilkoplinga: </translation>
    </message>
</context>
<context>
    <name>RDStereoMeter</name>
    <message>
        <source>L</source>
        <translation>V</translation>
    </message>
    <message>
        <source>R</source>
        <translation>H</translation>
    </message>
    <message>
        <source>CLIP</source>
        <translation>KLYPP</translation>
    </message>
</context>
<context>
    <name>RDSvc</name>
    <message>
        <source>The following events were not placed:
</source>
        <translation>Desse hendingane vart ikkje plasserte:
</translation>
    </message>
    <message>
        <source>[unknown cart]</source>
        <translation type="obsolete">[ukjend korg]</translation>
    </message>
    <message>
        <source>Autofill Errors
</source>
        <translation type="obsolete">Autofyll-feil
</translation>
    </message>
    <message>
        <source>Event Fill Errors
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log in use by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>invalid start time and/or length on inline traffic break.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>multiple inline traffic breaks not permitted within the same music event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>invalid start time and/or length on track marker.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unexpected event type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>invalid start time and/or length on note cart.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Note Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Track</source>
        <translation type="unfinished">Spor</translation>
    </message>
    <message>
        <source>Traffic Link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unexpected event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy of</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
